#
# spec file for package perl-HTML-Form
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name HTML-Form
Name:           perl-HTML-Form
Version:        6.11
Release:        1.7
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Class that represents an HTML form element
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/S/SI/SIMBABQUE/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(HTML::TokeParser)
BuildRequires:  perl(HTTP::Request) >= 6
BuildRequires:  perl(HTTP::Request::Common) >= 6.03
BuildRequires:  perl(HTTP::Response)
BuildRequires:  perl(Test::More) >= 0.96
BuildRequires:  perl(Test::Warnings)
BuildRequires:  perl(URI) >= 1.10
BuildRequires:  perl(parent)
Requires:       perl(HTML::TokeParser)
Requires:       perl(HTTP::Request) >= 6
Requires:       perl(HTTP::Request::Common) >= 6.03
Requires:       perl(Test::More) >= 0.96
Requires:       perl(URI) >= 1.10
Requires:       perl(parent)
%{perl_requires}

%description
Objects of the 'HTML::Form' class represents a single HTML '<form> ...
</form>' instance. A form consists of a sequence of inputs that usually
have names, and which can take on various values. The state of a form can
be tweaked and it can then be asked to provide HTTP::Request objects that
can be passed to the request() method of LWP::UserAgent.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes
%license LICENSE

%changelog
* Sun Feb 12 2023 Tina Müller <timueller+perl@suse.de>
- updated to 6.11
  see /usr/share/doc/packages/perl-HTML-Form/Changes
  6.11      2023-02-11 11:49:19Z
  - Perl::Tidy-ed the entire codebase (GH#42) (Julien Fiegehenn)
  - Split extra packages inside HTML::Form into their own module files
    and consolidate documentation (GH#43) (Julien Fiegehenn)
  - Added test to check unrecognized options to parse(). (GH#46) (Mohammad S Anwar)
* Tue Aug 23 2022 Tina Müller <timueller+perl@suse.de>
- updated to 6.10
  see /usr/share/doc/packages/perl-HTML-Form/Changes
  6.10      2022-08-22 13:20:12Z
  - Use "croak" instead of "die" to show errors from the perspective of the
    caller [RT#20499] (GH#29) (Julien Fiegehenn)
  - Remove the executable bit from a couple of tests (GH#41) (James Raspass)
  - <option>s within select fields without a name no longer get merged into
    the previous select field (GH#2) (Julien Fiegehenn)
  - find_input() can now take a reference to undef to explicitly find inputs
    that have no name (GH#2) (Julien Fiegehenn)
* Tue Aug 16 2022 Tina Müller <timueller+perl@suse.de>
- updated to 6.09
  see /usr/share/doc/packages/perl-HTML-Form/Changes
  6.09      2022-08-14 22:16:37Z
  - Replace "use vars" with "our" (GH#34) (James Raspass)
  - Remove superfluous "use lib" (GH#35) (James Raspass)
  - Replace "Test" with "Test::More" (GH#36) (James Raspass)
  - Remove superfluous variable copy (GH#37) (James Raspass)
  6.08      2022-08-14 09:26:10Z
  - Remove Authority section from dist.ini (GH#27) (Olaf Alders)
  - Allow buttons to not have a value (GH#8) (Felix Ostmann and Julien Fiegehenn)
  - The legacy API of FileInput fields now correctly supports setting a
    custom filename (GH#10) (Gil Magno and Julien Fiegehenn)
  - Allow undef filename for FileInput if there is a Content header (GH#30)
    (Julien Fiegehenn)
* Sat Feb 22 2020 <timueller+perl@suse.de>
- updated to 6.07
  see /usr/share/doc/packages/perl-HTML-Form/Changes
  6.07      2020-02-21 03:50:52Z
  - Restore =head1 NAME section to pod for HTML::Form
* Fri Feb 21 2020 <timueller+perl@suse.de>
- updated to 6.06
  see /usr/share/doc/packages/perl-HTML-Form/Changes
  6.06      2020-02-20 14:48:37Z
  - Change the behaviour of find_input in list context (GH#21) (E. Choroba)
  - Pod tweaks (GH#17) (Olaf Alders)
  - Add list context examples for find_input() (GH#20) (Olaf Alders)
  - Modernize some tests (GH#18) (Olaf Alders)
* Mon Oct  7 2019 <timueller+perl@suse.de>
- updated to 6.05
  see /usr/share/doc/packages/perl-HTML-Form/Changes
  6.05      2019-10-04 20:28:20Z
  - Update pod as requested in [RT#87689] (GH#16) (Lance Wicks and Julien
    Fiegehenn)
* Sat Mar 30 2019 Stephan Kulow <coolo@suse.com>
- updated to 6.04
  see /usr/share/doc/packages/perl-HTML-Form/Changes
* Wed Jul 24 2013 coolo@suse.com
- updated to 6.03
  Support the new HTML5 input types without warning
  Fix test failure when HTTP-Message 6.03 (or better) was installed [RT#75155]
* Mon Feb 20 2012 coolo@suse.com
- updated to 6.01
  Don't pick up label text from textarea [RT#72925]
  Restore perl-5.8.1 compatiblity.
* Mon Mar 14 2011 vcizek@novell.com
- initial package 6.00
  * created by cpanspec 1.78.03
